# OrderStatusEnum


## Enum

* `DRAFT` (value: `'Draft'`)

* `ACTIVE` (value: `'Active'`)

* `INACTIVE` (value: `'Inactive'`)

* `ARCHIVED` (value: `'Archived'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


